@@ -1,6 +1,7 @@
 #! /usr/bin/env python
 """
-Sample script that monitors smartcard insertion/removal and select DF_TELECOM on inserted cards
+Sample script that monitors smartcard insertion/removal and select
+DF_TELECOM on inserted cards
 
 __author__ = "http://www.gemalto.com"
 
@@ -32,34 +33,35 @@ from smartcard.CardMonitoring import CardMonitor, CardObserver
 from smartcard.util import *
 
 # define the apdus used in this script
-GET_RESPONSE = [0XA0, 0XC0, 00, 00 ]
+GET_RESPONSE = [0XA0, 0XC0, 00, 00]
 SELECT = [0xA0, 0xA4, 0x00, 0x00, 0x02]
 DF_TELECOM = [0x7F, 0x10]
 
 
 # a simple card observer that tries to select DF_TELECOM on an inserted card
-class selectDFTELECOMObserver( CardObserver ):
+class selectDFTELECOMObserver(CardObserver):
     """A simple card observer that is notified
     when cards are inserted/removed from the system and
     prints the list of cards
     """
-    def __init__( self ):
-        self.observer=ConsoleCardConnectionObserver()
 
-    def update( self, observable, (addedcards, removedcards) ):
+    def __init__(self):
+        self.observer = ConsoleCardConnectionObserver()
+
+    def update(self, observable, (addedcards, removedcards)):
         for card in addedcards:
-            print "+Inserted: ", toHexString( card.atr )
+            print "+Inserted: ", toHexString(card.atr)
             card.connection = card.createConnection()
             card.connection.connect()
-            card.connection.addObserver( self.observer )
-            apdu = SELECT+DF_TELECOM
-            response, sw1, sw2 = card.connection.transmit( apdu )
+            card.connection.addObserver(self.observer)
+            apdu = SELECT + DF_TELECOM
+            response, sw1, sw2 = card.connection.transmit(apdu)
             if sw1 == 0x9F:
                 apdu = GET_RESPONSE + [sw2]
-                response, sw1, sw2 = card.connection.transmit( apdu )
+                response, sw1, sw2 = card.connection.transmit(apdu)
 
         for card in removedcards:
-            print "-Removed: ", toHexString( card.atr )
+            print "-Removed: ", toHexString(card.atr)
 
 try:
     print "Insert or remove a SIM card in the system."
@@ -67,16 +69,16 @@ try:
     print ""
     cardmonitor = CardMonitor()
     selectobserver = selectDFTELECOMObserver()
-    cardmonitor.addObserver( selectobserver )
+    cardmonitor.addObserver(selectobserver)
 
     sleep(60)
 
     # don't forget to remove observer, or the
     # monitor will poll forever...
-    cardmonitor.deleteObserver( selectobserver )
+    cardmonitor.deleteObserver(selectobserver)
 
     import sys
-    if 'win32'==sys.platform:
+    if 'win32' == sys.platform:
         print 'press Enter to continue'
         sys.stdin.read(1)
 
