@@ -118,9 +118,8 @@ try:
             raise error, 'Failed to release context: ' + SCardGetErrorMessage(hresult)
         print 'Released context.'
 
-except:
-    import sys
-    print sys.exc_info()[0], ':', sys.exc_info()[1]
+except error, e:
+    print e
 
 import sys
 if 'win32' == sys.platform:
