@@ -24,20 +24,41 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
+import os
+import sys
 import os.path
 from smartcard.wx.SimpleSCardApp import *
 
 from SampleAPDUManagerPanel import SampleAPDUManagerPanel
 
-def main( argv ):
+
+def we_are_frozen():
+    """Returns whether we are frozen via py2exe.
+    This will affect how we find out where we are located.
+    From WhereAmI page on py2exe wiki."""
+
+    return hasattr(sys, "frozen")
+
+
+def module_path():
+    """ This will get us the program's directory,
+    even if we are frozen using py2exe. From WhereAmI page on py2exe wiki."""
+
+
+    if we_are_frozen():
+        return os.path.dirname( unicode(sys.executable, sys.getfilesystemencoding( )) )
+
+    return os.path.dirname(unicode(__file__, sys.getfilesystemencoding( )))
+
+def main(argv):
     app = SimpleSCardApp(
         appname='A tool to send apdu to a card',
         apppanel=SampleAPDUManagerPanel,
         appstyle=TR_SMARTCARD | TR_READER | PANEL_APDUTRACER,
-        appicon=os.path.join( os.path.dirname( __file__ ), 'images', 'mysmartcard.ico' ),
-        size=(800, 600) )
+        appicon=os.path.join( module_path(), 'images', 'mysmartcard.ico'),
+        size=(800, 600))
     app.MainLoop()
 
 if __name__ == "__main__":
     import sys
-    main( sys.argv )
+    main(sys.argv)
