@@ -24,17 +24,38 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 import os.path
+import sys
 from smartcard.wx.SimpleSCardApp import *
 
-def main( argv ):
+
+def we_are_frozen():
+    """Returns whether we are frozen via py2exe.
+    This will affect how we find out where we are located.
+    From WhereAmI page on py2exe wiki."""
+
+    return hasattr(sys, "frozen")
+
+
+def module_path():
+    """ This will get us the program's directory,
+    even if we are frozen using py2exe. From WhereAmI page on py2exe wiki."""
+
+
+    if we_are_frozen():
+        return os.path.dirname( unicode(sys.executable, sys.getfilesystemencoding( )) )
+
+    return os.path.dirname(unicode(__file__, sys.getfilesystemencoding( )))
+
+
+def main(argv):
     app = SimpleSCardApp(
         appname='A simple reader monitoring tool',
         apppanel=None,
         appstyle=TR_READER,
-        appicon=os.path.join( os.path.dirname( __file__ ), 'images', 'readerviewer.ico' ),
-        size=(800, 600) )
+        appicon=os.path.join(module_path(), 'images', 'readerviewer.ico'),
+        size=(800, 600))
     app.MainLoop()
 
 if __name__ == "__main__":
     import sys
-    main( sys.argv )
+    main(sys.argv)
