@@ -5,7 +5,7 @@ access smartcards and readers.
 
 __author__ = "gemalto http://www.gemalto.com"
 __date__ = "May 2010"
-__version__ = "1.6.10"
+__version__ = "1.6.12"
 
 Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
@@ -27,11 +27,8 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
-__all__ = [
-             'listReaders',
-             'Session'
-          ]
-
+__all__ = ['listReaders',
+             'Session']
 
 # for legacy only
 from smartcard.System import listReaders
