@@ -48,26 +48,25 @@ FEATURE_GET_TLV_PROPERTIES = 0x12
 FEATURE_CCID_ESC_COMMAND = 0x13
 
 Features = {
-"FEATURE_VERIFY_PIN_START"         : FEATURE_VERIFY_PIN_START,
-"FEATURE_VERIFY_PIN_FINISH"        : FEATURE_VERIFY_PIN_FINISH,
-"FEATURE_MODIFY_PIN_START"         : FEATURE_MODIFY_PIN_START,
-"FEATURE_MODIFY_PIN_FINISH"        : FEATURE_MODIFY_PIN_FINISH,
-"FEATURE_GET_KEY_PRESSED"          : FEATURE_GET_KEY_PRESSED,
-"FEATURE_VERIFY_PIN_DIRECT"        : FEATURE_VERIFY_PIN_DIRECT,
-"FEATURE_MODIFY_PIN_DIRECT"        : FEATURE_MODIFY_PIN_DIRECT,
-"FEATURE_MCT_READER_DIRECT"        : FEATURE_MCT_READER_DIRECT,
-"FEATURE_MCT_UNIVERSAL"            : FEATURE_MCT_UNIVERSAL,
-"FEATURE_IFD_PIN_PROPERTIES"       : FEATURE_IFD_PIN_PROPERTIES,
-"FEATURE_ABORT"                    : FEATURE_ABORT,
-"FEATURE_SET_SPE_MESSAGE"          : FEATURE_SET_SPE_MESSAGE,
-"FEATURE_VERIFY_PIN_DIRECT_APP_ID" : FEATURE_VERIFY_PIN_DIRECT_APP_ID,
-"FEATURE_MODIFY_PIN_DIRECT_APP_ID" : FEATURE_MODIFY_PIN_DIRECT_APP_ID,
-"FEATURE_WRITE_DISPLAY"            : FEATURE_WRITE_DISPLAY,
-"FEATURE_GET_KEY"                  : FEATURE_GET_KEY,
-"FEATURE_IFD_DISPLAY_PROPERTIES"   : FEATURE_IFD_DISPLAY_PROPERTIES,
-"FEATURE_GET_TLV_PROPERTIES"       : FEATURE_GET_TLV_PROPERTIES,
-"FEATURE_CCID_ESC_COMMAND"         : FEATURE_CCID_ESC_COMMAND
-}
+"FEATURE_VERIFY_PIN_START": FEATURE_VERIFY_PIN_START,
+"FEATURE_VERIFY_PIN_FINISH": FEATURE_VERIFY_PIN_FINISH,
+"FEATURE_MODIFY_PIN_START": FEATURE_MODIFY_PIN_START,
+"FEATURE_MODIFY_PIN_FINISH": FEATURE_MODIFY_PIN_FINISH,
+"FEATURE_GET_KEY_PRESSED": FEATURE_GET_KEY_PRESSED,
+"FEATURE_VERIFY_PIN_DIRECT": FEATURE_VERIFY_PIN_DIRECT,
+"FEATURE_MODIFY_PIN_DIRECT": FEATURE_MODIFY_PIN_DIRECT,
+"FEATURE_MCT_READER_DIRECT": FEATURE_MCT_READER_DIRECT,
+"FEATURE_MCT_UNIVERSAL": FEATURE_MCT_UNIVERSAL,
+"FEATURE_IFD_PIN_PROPERTIES": FEATURE_IFD_PIN_PROPERTIES,
+"FEATURE_ABORT": FEATURE_ABORT,
+"FEATURE_SET_SPE_MESSAGE": FEATURE_SET_SPE_MESSAGE,
+"FEATURE_VERIFY_PIN_DIRECT_APP_ID": FEATURE_VERIFY_PIN_DIRECT_APP_ID,
+"FEATURE_MODIFY_PIN_DIRECT_APP_ID": FEATURE_MODIFY_PIN_DIRECT_APP_ID,
+"FEATURE_WRITE_DISPLAY": FEATURE_WRITE_DISPLAY,
+"FEATURE_GET_KEY": FEATURE_GET_KEY,
+"FEATURE_IFD_DISPLAY_PROPERTIES": FEATURE_IFD_DISPLAY_PROPERTIES,
+"FEATURE_GET_TLV_PROPERTIES": FEATURE_GET_TLV_PROPERTIES,
+"FEATURE_CCID_ESC_COMMAND": FEATURE_CCID_ESC_COMMAND}
 
 # properties returned by FEATURE_GET_TLV_PROPERTIES
 PCSCv2_PART10_PROPERTY_wLcdLayout = 1
@@ -81,15 +80,14 @@ PCSCv2_PART10_PROPERTY_sFirmwareID = 8
 PCSCv2_PART10_PROPERTY_bPPDUSupport = 9
 
 Properties = {
-"PCSCv2_PART10_PROPERTY_wLcdLayout" : PCSCv2_PART10_PROPERTY_wLcdLayout,
+"PCSCv2_PART10_PROPERTY_wLcdLayout": PCSCv2_PART10_PROPERTY_wLcdLayout,
 "PCSCv2_PART10_PROPERTY_bEntryValidationCondition": PCSCv2_PART10_PROPERTY_bEntryValidationCondition,
 "PCSCv2_PART10_PROPERTY_bTimeOut2": PCSCv2_PART10_PROPERTY_bTimeOut2,
 "PCSCv2_PART10_PROPERTY_wLcdMaxCharacters": PCSCv2_PART10_PROPERTY_wLcdMaxCharacters,
 "PCSCv2_PART10_PROPERTY_wLcdMaxLines": PCSCv2_PART10_PROPERTY_wLcdMaxLines,
 "PCSCv2_PART10_PROPERTY_bMinPINSize": PCSCv2_PART10_PROPERTY_bMinPINSize,
 "PCSCv2_PART10_PROPERTY_bMaxPINSize": PCSCv2_PART10_PROPERTY_bMaxPINSize,
-"PCSCv2_PART10_PROPERTY_sFirmwareID": PCSCv2_PART10_PROPERTY_sFirmwareID
-}
+"PCSCv2_PART10_PROPERTY_sFirmwareID": PCSCv2_PART10_PROPERTY_sFirmwareID}
 
 # we already have:       Features['FEATURE_x'] = FEATURE_x
 # we will now also have: Features[FEATURE_x] = 'FEATURE_x'
@@ -103,9 +101,10 @@ for k in Properties.keys():
 def getFeatureRequest(cardConnection):
     """ Get the list of Part10 features supported by the reader.
 
-    cardConnection: CardConnection object
+    @param cardConnection: L{CardConnection} object
 
-    return: a list of list [[tag1, value1], [tag2, value2]]
+    @rtype: list
+    @return: a list of list [[tag1, value1], [tag2, value2]]
     """
     response = cardConnection.control(CM_IOCTL_GET_FEATURE_REQUEST, [])
     features = []
@@ -123,10 +122,10 @@ def getFeatureRequest(cardConnection):
 def hasFeature(featureList, feature):
     """ return the controlCode for a feature or None
 
-    feature:     feature to look for
-    featureList: feature list as returned by getFeatureRequest()
+    @param feature:     feature to look for
+    @param featureList: feature list as returned by L{getFeatureRequest()}
 
-    return: feature value or None
+    @return: feature value or None
     """
     for f in featureList:
         if f[0] == feature or Features[f[0]] == feature:
@@ -136,18 +135,19 @@ def hasFeature(featureList, feature):
 def getPinProperties(cardConnection, featureList=None, controlCode=None):
     """ return the PIN_PROPERTIES structure
 
-    cardConnection: CardConnection object
-    featureList: feature list as returned by getFeatureRequest()
-    controlCode: control code for FEATURE_IFD_PIN_PROPERTIES
+    @param cardConnection: L{CardConnection} object
+    @param featureList: feature list as returned by L{getFeatureRequest()}
+    @param controlCode: control code for L{FEATURE_IFD_PIN_PROPERTIES}
 
-    return: a dict """
+    @rtype: dict
+    @return: a dict """
     if controlCode is None:
         if featureList is None:
             featureList = getFeatureRequest(cardConnection)
         controlCode = hasFeature(featureList, FEATURE_IFD_PIN_PROPERTIES)
 
     if controlCode is None:
-        return { 'raw': [] }
+        return {'raw': []}
 
     response = cardConnection.control(controlCode, [])
     d = {
@@ -155,8 +155,7 @@ def getPinProperties(cardConnection, featureList=None, controlCode=None):
             'LcdLayoutX': response[0],
             'LcdLayoutY': response[1],
             'EntryValidationCondition': response[2],
-            'TimeOut2': response[3]
-        }
+            'TimeOut2': response[3]}
 
     return d
 
@@ -164,18 +163,19 @@ def getPinProperties(cardConnection, featureList=None, controlCode=None):
 def getTlvProperties(cardConnection, featureList=None, controlCode=None):
     """ return the GET_TLV_PROPERTIES structure
 
-    cardConnection: CardConnection object
-    featureList: feature list as returned by getFeatureRequest()
-    controlCode: control code for FEATURE_GET_TLV_PROPERTIES
+    @param cardConnection: L{CardConnection} object
+    @param featureList: feature list as returned by L{getFeatureRequest()}
+    @param controlCode: control code for L{FEATURE_GET_TLV_PROPERTIES}
 
-    return: a dict """
+    @rtype: dict
+    @return: a dict """
     if controlCode is None:
         if featureList is None:
             featureList = getFeatureRequest(cardConnection)
         controlCode = hasFeature(featureList, FEATURE_GET_TLV_PROPERTIES)
 
     if controlCode is None:
-        return { 'raw': [] }
+        return {'raw': []}
 
     response = cardConnection.control(controlCode, [])
     d = {
