@@ -1,5 +1,5 @@
 /*==============================================================================
-Copyright 2001-2009 gemalto
+Copyright 2001-2010 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -232,30 +232,42 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 // These functions are not available on Max OS X Tiger
 //
 #ifndef __TIGER__
-    WINSCARDAPI SCARDRETCODE
+    static WINSCARDAPI SCARDRETCODE
     WINAPI _defaultSCARDISVALIDCONTEXT(
         IN      SCARDCONTEXT hContext)
     {
+		(void)hContext;
+
         return SCARD_E_NO_SERVICE;
     }
 
-    WINSCARDAPI SCARDRETCODE
+    static WINSCARDAPI SCARDRETCODE
     WINAPI _defaultSCARDGETATTRIB(
         IN SCARDHANDLE hCard,
         IN SCARDDWORDARG dwAttrId,
         OUT LPBYTE pbAttr,
         IN OUT SCARDDWORDARG* pcbAttrLen)
     {
+		(void)hCard;
+		(void)dwAttrId;
+		(void)pbAttr;
+		(void)pcbAttrLen;
+
         return SCARD_E_NO_SERVICE;
     }
 
-    WINSCARDAPI SCARDRETCODE
+    static WINSCARDAPI SCARDRETCODE
     WINAPI _defaultSCARDSETATTRIB(
         IN SCARDHANDLE hCard,
         IN SCARDDWORDARG dwAttrId,
         IN LPCBYTE pbAttr,
         IN SCARDDWORDARG cbAttrLen)
     {
+		(void)hCard;
+		(void)dwAttrId;
+		(void)pbAttr;
+		(void)cbAttrLen;
+
         return SCARD_E_NO_SERVICE;
     }
 
@@ -269,7 +281,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 // SCardControl does not have the same prototype on Mac OS X Tiger
 //
 #ifdef __TIGER__
-    WINSCARDAPI SCARDRETCODE
+    static WINSCARDAPI SCARDRETCODE
     WINAPI _defaultSCARDCONTROL(
         IN      SCARDHANDLE hCard,
         IN      const unsigned char* lpInBuffer,
@@ -280,7 +292,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
         return SCARD_E_NO_SERVICE;
     }
 #else // !__TIGER__
-    WINSCARDAPI SCARDRETCODE
+    static WINSCARDAPI SCARDRETCODE
     WINAPI _defaultSCARDCONTROL(
         IN      SCARDHANDLE hCard,
         IN      SCARDDWORDARG dwControlCode,
@@ -290,6 +302,14 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
         IN      SCARDDWORDARG nOutBufferSize,
         OUT     SCARDDWORDARG* lpBytesReturned)
     {
+        (void)hCard;
+        (void)dwControlCode;
+        (void)lpInBuffer;
+        (void)nInBufferSize;
+        (void)lpOutBuffer;
+        (void)nOutBufferSize;
+        (void)lpBytesReturned;
+
         return SCARD_E_NO_SERVICE;
     }
 #endif // __TIGER__
@@ -299,7 +319,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 // some pcsclite versions (e.g. on Max OS X Tiger) have no pcsc_stringify
 // this function was taken from pcsclite
 //
-char* _defaultPCSCSTRINGIFYERROR( SCARDRETCODE pcscError )
+static char* _defaultPCSCSTRINGIFYERROR( SCARDRETCODE pcscError )
 {
     static char strError[75];
 
@@ -414,7 +434,7 @@ char* _defaultPCSCSTRINGIFYERROR( SCARDRETCODE pcscError )
             strncpy( strError, "Service was stopped.", sizeof( strError ) );
             break;
         default:
-            snprintf(strError, sizeof(strError)-1, "Unkown error: %ld, 0x%08lx", (long)pcscError, (long unsigned int)pcscError);
+            snprintf(strError, sizeof(strError)-1, "Unknown error: %ld, 0x%08lx", (long)pcscError, (long unsigned int)pcscError);
     };
 
     // zero terminates string
@@ -424,28 +444,34 @@ char* _defaultPCSCSTRINGIFYERROR( SCARDRETCODE pcscError )
 }
 #endif
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDBEGINTRANSACTION(
     IN      SCARDHANDLE hCard)
 {
+	(void)hCard;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDCANCEL(
     IN      SCARDCONTEXT hContext)
 {
+	(void)hContext;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDCANCELTRANSACTION(
     IN      SCARDHANDLE hCard)
 {
+	(void)hCard;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDCONNECTA(
     IN      SCARDCONTEXT hContext,
     IN      LPCTSTR szReader,
@@ -454,73 +480,108 @@ WINAPI _defaultSCARDCONNECTA(
     OUT     LPSCARDHANDLE phCard,
     OUT     SCARDDWORDARG* pdwActiveProtocol)
 {
+    (void)hContext;
+    (void)szReader;
+    (void)dwShareMode;
+    (void)dwPreferredProtocols;
+    (void)phCard;
+    (void)pdwActiveProtocol;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDDISCONNECT(
     IN      SCARDHANDLE hCard,
     IN      SCARDDWORDARG dwDisposition)
 {
+    (void)hCard;
+    (void)dwDisposition;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDENDTRANSACTION(
     IN      SCARDHANDLE hCard,
     IN      SCARDDWORDARG dwDisposition)
 {
+    (void)hCard;
+    (void)dwDisposition;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDESTABLISHCONTEXT(
     IN  SCARDDWORDARG dwScope,
     IN  LPCVOID pvReserved1,
     IN  LPCVOID pvReserved2,
     OUT LPSCARDCONTEXT phContext)
 {
+    (void)dwScope;
+    (void)pvReserved1;
+    (void)pvReserved2;
+    (void)phContext;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDFREEMEMORY(
     IN SCARDCONTEXT hContext,
     IN LPCVOID pvMem)
 {
+    (void)hContext;
+    (void)pvMem;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDGETSTATUSCHANGEA(
     IN      SCARDCONTEXT hContext,
     IN      SCARDDWORDARG dwTimeout,
     IN OUT  LPSCARD_READERSTATEA rgReaderStates,
     IN      SCARDDWORDARG cReaders)
 {
+    (void)hContext;
+    (void)dwTimeout;
+    (void)rgReaderStates;
+    (void)cReaders;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDLISTREADERSA(
     IN      SCARDCONTEXT hContext,
     IN      LPCTSTR mszGroups,
     OUT     LPTSTR mszReaders,
     IN OUT  SCARDDWORDARG* pcchReaders)
 {
+    (void)hContext;
+    (void)mszGroups;
+    (void)mszReaders;
+    (void)pcchReaders;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDLISTREADERGROUPSA(
     IN      SCARDCONTEXT hContext,
     OUT     LPTSTR mszGroups,
     IN OUT  SCARDDWORDARG* pcchGroups)
 {
+    (void)hContext;
+    (void)mszGroups;
+    (void)pcchGroups;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDRECONNECT(
     IN      SCARDHANDLE hCard,
     IN      SCARDDWORDARG dwShareMode,
@@ -528,17 +589,25 @@ WINAPI _defaultSCARDRECONNECT(
     IN      SCARDDWORDARG dwInitialization,
     OUT     SCARDDWORDARG* pdwActiveProtocol)
 {
+    (void)hCard;
+    (void)dwShareMode;
+    (void)dwPreferredProtocols;
+    (void)dwInitialization;
+    (void)pdwActiveProtocol;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDRELEASECONTEXT(
     IN      SCARDCONTEXT hContext)
 {
+    (void)hContext;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDSTATUSA(
     IN SCARDHANDLE hCard,
     OUT LPTSTR szReaderName,
@@ -548,10 +617,18 @@ WINAPI _defaultSCARDSTATUSA(
     OUT LPBYTE pbAtr,
     IN OUT SCARDDWORDARG* pcbAtrLen)
 {
+    (void)hCard;
+    (void)szReaderName;
+    (void)pcchReaderLen;
+    (void)pdwState;
+    (void)pdwProtocol;
+    (void)pbAtr;
+    (void)pcbAtrLen;
+
     return SCARD_E_NO_SERVICE;
 }
 
-WINSCARDAPI SCARDRETCODE
+static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDTRANSMIT(
     IN SCARDHANDLE hCard,
     IN LPCSCARD_IO_REQUEST pioSendPci,
@@ -561,6 +638,14 @@ WINAPI _defaultSCARDTRANSMIT(
     OUT LPBYTE pbRecvBuffer,
     IN OUT SCARDDWORDARG* pcbRecvLength)
 {
+    (void)hCard;
+    (void)pioSendPci;
+    (void)pbSendBuffer;
+    (void)cbSendLength;
+    (void)pioRecvPci;
+    (void)pbRecvBuffer;
+    (void)pcbRecvLength;
+
     return SCARD_E_NO_SERVICE;
 }
 
@@ -668,7 +753,7 @@ long winscard_init(void)
 
         void* handle=NULL;
         char* dlsym_error;
-        char *lib = NULL;
+        const char *lib = NULL;
         #ifdef __APPLE__
             lib = "/System/Library/Frameworks/PCSC.framework/PCSC";
         #else
@@ -677,7 +762,6 @@ long winscard_init(void)
 
         if( bFirstCall )
         {
-            bFirstCall=FALSE;
             dlerror();
             handle = dlopen( lib, RTLD_NOW );
             if( NULL!=handle )
@@ -733,6 +817,7 @@ long winscard_init(void)
                     printf( "Failed to dlopen %s: %s!", lib, (dlsym_error==NULL) ? "" : (char*)dlsym_error );
                 }
             }
+            bFirstCall=FALSE;
          }
     #endif // PCSCLITE
     return lRetCode;
